package com.op.wms.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.op.wms.mapper.OdsProcureOrderMapper;
import com.op.wms.domain.OdsProcureOrder;
import com.op.wms.service.IOdsProcureOrderService;

/**
 * 包材采购单Service业务层处理
 * 
 * @author Open Platform
 * @date 2023-07-06
 */
@Service
public class OdsProcureOrderServiceImpl implements IOdsProcureOrderService {
	@Autowired
	private OdsProcureOrderMapper odsProcureOrderMapper;

	/**
	 * 查询包材采购单
	 * 
	 * @param ID 包材采购单主键
	 * @return 包材采购单
	 */
	@Override
	public OdsProcureOrder selectOdsProcureOrderByID(String ID) {
		return odsProcureOrderMapper.selectOdsProcureOrderByID(ID);
	}

	/**
	 * 查询包材采购单列表
	 * 
	 * @param odsProcureOrder 包材采购单
	 * @return 包材采购单
	 */
	@Override
	public List<OdsProcureOrder> selectOdsProcureOrderList(OdsProcureOrder odsProcureOrder) {
		return odsProcureOrderMapper.selectOdsProcureOrderList(odsProcureOrder);
	}

	/**
	 * 新增包材采购单
	 * 
	 * @param odsProcureOrder 包材采购单
	 * @return 结果
	 */
	@Override
	public int insertOdsProcureOrder(OdsProcureOrder odsProcureOrder) {
		return odsProcureOrderMapper.insertOdsProcureOrder(odsProcureOrder);
	}

	/**
	 * 修改包材采购单
	 * 
	 * @param odsProcureOrder 包材采购单
	 * @return 结果
	 */
	@Override
	public int updateOdsProcureOrder(OdsProcureOrder odsProcureOrder) {
		return odsProcureOrderMapper.updateOdsProcureOrder(odsProcureOrder);
	}

	/**
	 * 批量删除包材采购单
	 * 
	 * @param IDs 需要删除的包材采购单主键
	 * @return 结果
	 */
	@Override
	public int deleteOdsProcureOrderByIDs(String[] IDs) {
		return odsProcureOrderMapper.deleteOdsProcureOrderByIDs(IDs);
	}

	/**
	 * 删除包材采购单信息
	 * 
	 * @param ID 包材采购单主键
	 * @return 结果
	 */
	@Override
	public int deleteOdsProcureOrderByID(String ID) {
		return odsProcureOrderMapper.deleteOdsProcureOrderByID(ID);
	}
}
