package com.op.wms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.op.common.log.annotation.Log;
import com.op.common.log.enums.BusinessType;
import com.op.common.security.annotation.RequiresPermissions;
import com.op.wms.domain.OdsProcureOrder;
import com.op.wms.service.IOdsProcureOrderService;
import com.op.common.core.web.controller.BaseController;
import com.op.common.core.web.domain.AjaxResult;
import com.op.common.core.utils.poi.ExcelUtil;
import com.op.common.core.web.page.TableDataInfo;

/**
 * 包材采购单Controller
 * 
 * @author Open Platform
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/order")
public class OdsProcureOrderController extends BaseController {
	@Autowired
	private IOdsProcureOrderService odsProcureOrderService;

	/**
	 * 查询包材采购单列表
	 */
	@RequiresPermissions("wms:order:list")
	@GetMapping("/list")
	public TableDataInfo list(OdsProcureOrder odsProcureOrder) {
		startPage();
		List<OdsProcureOrder> list = odsProcureOrderService.selectOdsProcureOrderList(odsProcureOrder);
		return getDataTable(list);
	}

	/**
	 * 导出包材采购单列表
	 */
	@RequiresPermissions("wms:order:export")
	@Log(title = "包材采购单", businessType = BusinessType.EXPORT)
	@PostMapping("/export")
	public void export(HttpServletResponse response, OdsProcureOrder odsProcureOrder) {
		List<OdsProcureOrder> list = odsProcureOrderService.selectOdsProcureOrderList(odsProcureOrder);
		ExcelUtil<OdsProcureOrder> util = new ExcelUtil<OdsProcureOrder>(OdsProcureOrder.class);
		util.exportExcel(response, list, "包材采购单数据");
	}

	/**
	 * 获取包材采购单详细信息
	 */
	@RequiresPermissions("wms:order:query")
	@GetMapping(value = "/{ID}")
	public AjaxResult getInfo(@PathVariable("ID") String ID) {
		return success(odsProcureOrderService.selectOdsProcureOrderByID(ID));
	}

	/**
	 * 新增包材采购单
	 */
	@RequiresPermissions("wms:order:add")
	@Log(title = "包材采购单", businessType = BusinessType.INSERT)
	@PostMapping
	public AjaxResult add(@RequestBody OdsProcureOrder odsProcureOrder) {
		return toAjax(odsProcureOrderService.insertOdsProcureOrder(odsProcureOrder));
	}

	/**
	 * 修改包材采购单
	 */
	@RequiresPermissions("wms:order:edit")
	@Log(title = "包材采购单", businessType = BusinessType.UPDATE)
	@PutMapping
	public AjaxResult edit(@RequestBody OdsProcureOrder odsProcureOrder) {
		return toAjax(odsProcureOrderService.updateOdsProcureOrder(odsProcureOrder));
	}

	/**
	 * 删除包材采购单
	 */
	@RequiresPermissions("wms:order:remove")
	@Log(title = "包材采购单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
	public AjaxResult remove(@PathVariable String[] IDs) {
		return toAjax(odsProcureOrderService.deleteOdsProcureOrderByIDs(IDs));
	}
}
